@@ -1,14 +1,19 @@
 
 
-class InvalidContentTypeError(Exception):
-    """Raised when Snapshot command returns an invalid JPEG file"""
+class ReolinkError(Exception):
     pass
 
-class SnapshotIsNotValidFileTypeError(Exception):
+
+class InvalidContentTypeError(ReolinkError):
     """Raised when Snapshot command returns an invalid JPEG file"""
     pass
 
 
-class CredentialsInvalidError(Exception):
+class SnapshotIsNotValidFileTypeError(ReolinkError):
+    """Raised when Snapshot command returns an invalid JPEG file"""
+    pass
+
+
+class CredentialsInvalidError(ReolinkError):
     """Raised when an API call returns a credential issue"""
     pass
